[clutter/wip/actor-content: 19/22] docs: Update the API reference



commit e45e0d325a51f2b08afe852e19b6f9f99d18d689
Author: Emmanuele Bassi <ebassi linux intel com>
Date:   Fri Dec 10 16:05:04 2010 +0000

    docs: Update the API reference

 clutter/clutter-rgba.c                     |  104 ++++++++++++++++++++++++----
 doc/reference/clutter/Makefile.am          |    1 +
 doc/reference/clutter/clutter-docs.xml.in  |    8 ++
 doc/reference/clutter/clutter-sections.txt |   90 ++++++++++++++++++++++++
 doc/reference/clutter/clutter.types        |    4 +
 tests/interactive/test-image-content.c     |    2 +-
 tests/interactive/test-rgba-content.c      |    2 +-
 7 files changed, 195 insertions(+), 16 deletions(-)
---
diff --git a/doc/reference/clutter/Makefile.am b/doc/reference/clutter/Makefile.am
index 82b8a83..0c7fc5b 100644
--- a/doc/reference/clutter/Makefile.am
+++ b/doc/reference/clutter/Makefile.am
@@ -96,6 +96,7 @@ IGNORE_HFILES=\
 	egl 				\
 	evdev				\
 	glx 				\
+	image-loaders			\
 	osx 				\
 	x11 				\
 	wayland				\
diff --git a/doc/reference/clutter/clutter-docs.xml.in b/doc/reference/clutter/clutter-docs.xml.in
index 1e985ed..81eaef4 100644
--- a/doc/reference/clutter/clutter-docs.xml.in
+++ b/doc/reference/clutter/clutter-docs.xml.in
@@ -64,6 +64,7 @@
       <xi:include href="xml/clutter-action.xml"/>
       <xi:include href="xml/clutter-constraint.xml"/>
       <xi:include href="xml/clutter-effect.xml"/>
+      <xi:include href="xml/clutter-content.xml"/>
     </chapter>
 
     <chapter>
@@ -122,6 +123,13 @@
       <xi:include href="xml/clutter-page-turn-effect.xml"/>
     </chapter>
 
+    <chapter>
+      <title>Content</title>
+
+      <xi:include href="xml/clutter-image.xml"/>
+      <xi:include href="xml/clutter-rgba.xml"/>
+    </chapter>
+
   </part>
 
   <part id="clutteranimation">
diff --git a/doc/reference/clutter/clutter-sections.txt b/doc/reference/clutter/clutter-sections.txt
index 3bad594..395cd55 100644
--- a/doc/reference/clutter/clutter-sections.txt
+++ b/doc/reference/clutter/clutter-sections.txt
@@ -279,6 +279,7 @@ CLUTTER_CALLBACK
 ClutterCallback
 ClutterActor
 ClutterActorClass
+clutter_actor_new
 clutter_actor_set_flags
 clutter_actor_unset_flags
 clutter_actor_get_flags
@@ -298,6 +299,8 @@ clutter_actor_event
 clutter_actor_should_pick_paint
 clutter_actor_map
 clutter_actor_unmap
+clutter_actor_set_content
+clutter_actor_get_content
 
 <SUBSECTION>
 ClutterAllocationFlags
@@ -2659,3 +2662,90 @@ CLUTTER_TYPE_SNAP_CONSTRAINT
 ClutterSnapConstraintClass
 clutter_snap_constraint_get_type
 </SECTION>
+
+<SECTION>
+<FILE>clutter-content</FILE>
+ClutterContent
+ClutterContentIface
+clutter_content_apply_mask
+clutter_content_paint_content
+clutter_content_get_paint_volume
+clutter_content_invalidate
+<SUBSECTION Standard>
+CLUTTER_TYPE_CONTENT
+CLUTTER_CONTENT
+CLUTTER_IS_CONTENT
+CLUTTER_CONTENT_GET_IFACE
+<SUBSECTION Private>
+clutter_content_get_type
+</SECTION>
+
+<SECTION>
+<FILE>clutter-rgba</FILE>
+ClutterRGBA
+clutter_rgba_new
+clutter_rgba_new_from_color
+clutter_rgba_new_from_string
+<SUBSECTION>
+clutter_rgba_set_red
+clutter_rgba_get_red
+clutter_rgba_set_green
+clutter_rgba_get_green
+clutter_rgba_set_blue
+clutter_rgba_get_blue
+clutter_rgba_set_alpha
+clutter_rgba_get_alpha
+<SUBSECTION>
+clutter_rgba_set_color
+clutter_rgba_set_string
+<SUBSECTION Standard>
+CLUTTER_TYPE_RGBA
+CLUTTER_RGBA
+CLUTTER_IS_RGBA
+<SUBSECTION Private>
+clutter_rgba_get_type
+</SECTION>
+
+<SECTION>
+<FILE>clutter-image</FILE>
+ClutterImage
+ClutterImageClass
+clutter_image_new
+<SUBSECTION>
+clutter_image_load_from_data
+clutter_image_load
+clutter_image_load_async
+clutter_image_load_finish
+<SUBSECTION>
+clutter_image_get_size
+<SUBSECTION>
+ClutterImageError
+CLUTTER_IMAGE_ERROR
+<SUBSECTION Standard>
+CLUTTER_TYPE_IMAGE
+CLUTTER_IMAGE
+CLUTTER_IMAGE_CLASS
+CLUTTER_IS_IMAGE
+CLUTTER_IS_IMAGE_CLASS
+CLUTTER_IMAGE_GET_CLASS
+<SUBSECTION Private>
+ClutterImagePrivate
+clutter_image_get_type
+clutter_image_error_quark
+</SECTION>
+
+<SECTION>
+<FILE>clutter-image-loader</FILE>
+ClutterImageLoader
+ClutterImageLoaderClass
+CLUTTER_IMAGE_LOADER_EXTENSION_POINT_NAME
+<SUBSECTION Standard>
+CLUTTER_TYPE_IMAGE_LOADER
+CLUTTER_IMAGE_LOADER
+CLUTTER_IMAGE_LOADER_CLASS
+CLUTTER_IMAGE_LOADER_GET_CLASS
+CLUTTER_IS_IMAGE_LOADER
+CLUTTER_IS_IMAGE_LOADER_CLASS
+<SUBSECTION Private>
+clutter_image_loader_get_type
+</SECTION>
diff --git a/doc/reference/clutter/clutter.types b/doc/reference/clutter/clutter.types
index f55aaa9..d35435a 100644
--- a/doc/reference/clutter/clutter.types
+++ b/doc/reference/clutter/clutter.types
@@ -27,6 +27,7 @@ clutter_click_action_get_type
 clutter_clone_get_type
 clutter_colorize_effect_get_type
 clutter_constraint_get_type
+clutter_content_get_type
 clutter_deform_effect_get_type
 clutter_desaturate_effect_get_type
 clutter_device_manager_get_type
@@ -35,6 +36,8 @@ clutter_effect_get_type
 clutter_fixed_layout_get_type
 clutter_flow_layout_get_type
 clutter_group_get_type
+clutter_image_loader_get_type
+clutter_image_get_type
 clutter_input_device_get_type
 clutter_interval_get_type
 clutter_layout_manager_get_type
@@ -48,6 +51,7 @@ clutter_page_turn_effect_get_type
 clutter_path_constraint_get_type
 clutter_path_get_type
 clutter_rectangle_get_type
+clutter_rgba_get_type
 clutter_score_get_type
 clutter_scriptable_get_type
 clutter_script_get_type
diff --git a/tests/interactive/test-image-content.c b/tests/interactive/test-image-content.c
index 8c20746..52a580d 100644
--- a/tests/interactive/test-image-content.c
+++ b/tests/interactive/test-image-content.c
@@ -79,7 +79,7 @@ test_image_content_main (int   argc,
       last_x = PADDING + SPACING;
       for (j = 0; j < n_cols; j++)
         {
-          ClutterActor *rect = g_object_new (CLUTTER_TYPE_ACTOR, NULL);
+          ClutterActor *rect = clutter_actor_new ();
 
           clutter_actor_set_position (rect, last_x, last_y);
           clutter_actor_set_size (rect, RECT_SIZE, RECT_SIZE);
diff --git a/tests/interactive/test-rgba-content.c b/tests/interactive/test-rgba-content.c
index dbb3713..a776407 100644
--- a/tests/interactive/test-rgba-content.c
+++ b/tests/interactive/test-rgba-content.c
@@ -54,7 +54,7 @@ test_rgba_content_main (int   argc,
       last_x = PADDING + SPACING;
       for (j = 0; j < n_cols; j++)
         {
-          ClutterActor *rect = g_object_new (CLUTTER_TYPE_ACTOR, NULL);
+          ClutterActor *rect = clutter_actor_new ();
 
           clutter_actor_set_position (rect, last_x, last_y);
           clutter_actor_set_size (rect, RECT_SIZE, RECT_SIZE);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/clutter/clutter-rgba.c b/clutter/clutter-rgba.c
index 3fec992..7e84e83 100644
--- a/clutter/clutter-rgba.c
+++ b/clutter/clutter-rgba.c
@@ -191,14 +191,14 @@ clutter_rgba_class_init (ClutterRGBAClass *klass)
   /**
    * ClutterRGBA:red:
    *
    * The value of the red channel.
    *
    * Since: 1.6
    */
   obj_props[PROP_RED] =
     g_param_spec_double ("red",
                          P_("Red"),
-                         P_("The red value"),
+                         P_("The intensity of the red channel"),
                          0.0, 1.0,
                          0.0,
                          CLUTTER_PARAM_READWRITE);
@@ -206,14 +206,14 @@ clutter_rgba_class_init (ClutterRGBAClass *klass)
   /**
    * ClutterRGBA:green:
    *
    * The value of the green channel.
    *
    * Since: 1.6
    */
   obj_props[PROP_GREEN] =
     g_param_spec_double ("green",
                          P_("Green"),
-                         P_("The green value"),
+                         P_("The intensity of the green channel"),
                          0.0, 1.0,
                          0.0,
                          CLUTTER_PARAM_READWRITE);
@@ -221,14 +221,14 @@ clutter_rgba_class_init (ClutterRGBAClass *klass)
   /**
    * ClutterRGBA:blue:
    *
    * The value of the blue channel.
    *
    * Since: 1.6
    */
   obj_props[PROP_BLUE] =
     g_param_spec_double ("blue",
                          P_("Blue"),
-                         P_("The blue value"),
+                         P_("The intensity of the blue channel"),
                          0.0, 1.0,
                          0.0,
                          CLUTTER_PARAM_READWRITE);
@@ -236,14 +236,14 @@ clutter_rgba_class_init (ClutterRGBAClass *klass)
   /**
    * ClutterRGBA:alpha:
    *
-   * The value of the alpha channel.
+   * The opacity of the color.
    *
    * Since: 1.6
    */
   obj_props[PROP_ALPHA] =
     g_param_spec_double ("alpha",
                          P_("Alpha"),
-                         P_("The alpha value"),
+                         P_("The opacity of the color"),
                          0.0, 1.0,
                          0.0,
                          CLUTTER_PARAM_READWRITE);
@@ -289,10 +289,10 @@ clutter_rgba_init (ClutterRGBA *self)
 
 /**
  * clutter_rgba_new:
  * @red: the value of the red channel, between 0 and 1
  * @green: the value of the green channel, between 0 and 1
  * @blue: the value of the blue channel, between 0 and 1
  * @alpha: the value of the alpha channel, between 0 and 1
  *
  * Creates a new #ClutterRGBA object for the given color. This
  * object can be used to paint a solid color inside a #ClutterActor,
@@ -354,6 +354,15 @@ clutter_rgba_new_from_string (const gchar *string)
                        NULL);
 }
 
+/**
+ * clutter_rgba_set_red:
+ * @self: a #ClutterRGBA
+ * @red: the intensity of the red channel
+ *
+ * Sets the intensity of the red channel of a #ClutterRGBA.
+ *
+ * Since: 1.6
+ */
 void
 clutter_rgba_set_red (ClutterRGBA *self,
                       gdouble      red)
@@ -370,6 +379,16 @@ clutter_rgba_set_red (ClutterRGBA *self,
   g_object_notify_by_pspec (G_OBJECT (self), obj_props[PROP_RED]);
 }
 
+/**
+ * clutter_rgba_get_red:
+ * @self: a #ClutterRGBA
+ *
+ * Retrieves the intensity of the red channel of a #ClutterRGBA.
+ *
+ * Return value: the intensity, between 0.0 and 1.0
+ *
+ * Since: 1.6
+ */
 gdouble
 clutter_rgba_get_red (ClutterRGBA *self)
 {
@@ -378,6 +397,15 @@ clutter_rgba_get_red (ClutterRGBA *self)
   return self->red;
 }
 
+/**
+ * clutter_rgba_set_green:
+ * @self: a #ClutterRGBA
+ * @green: the intensity of the green channel
+ *
+ * Sets the intensity of the green channel of a #ClutterRGBA.
+ *
+ * Since: 1.6
+ */
 void
 clutter_rgba_set_green (ClutterRGBA *self,
                         gdouble      green)
@@ -394,6 +422,16 @@ clutter_rgba_set_green (ClutterRGBA *self,
   g_object_notify_by_pspec (G_OBJECT (self), obj_props[PROP_GREEN]);
 }
 
+/**
+ * clutter_rgba_get_green:
+ * @self: a #ClutterRGBA
+ *
+ * Retrieves the intensity of the green channel of a #ClutterRGBA.
+ *
+ * Return value: the intensity, between 0.0 and 1.0
+ *
+ * Since: 1.6
+ */
 gdouble
 clutter_rgba_get_green (ClutterRGBA *self)
 {
@@ -402,6 +440,15 @@ clutter_rgba_get_green (ClutterRGBA *self)
   return self->green;
 }
 
+/**
+ * clutter_rgba_set_blue:
+ * @self: a #ClutterRGBA
+ * @blue: the intensity of the blue channel
+ *
+ * Sets the intensity of the blue channel of a #ClutterRGBA.
+ *
+ * Since: 1.6
+ */
 void
 clutter_rgba_set_blue (ClutterRGBA *self,
                        gdouble      blue)
@@ -418,6 +465,16 @@ clutter_rgba_set_blue (ClutterRGBA *self,
   g_object_notify_by_pspec (G_OBJECT (self), obj_props[PROP_BLUE]);
 }
 
+/**
+ * clutter_rgba_get_blue:
+ * @self: a #ClutterRGBA
+ *
+ * Retrieves the intensity of the blue channel of a #ClutterRGBA.
+ *
+ * Return value: the intensity, between 0.0 and 1.0
+ *
+ * Since: 1.6
+ */
 gdouble
 clutter_rgba_get_blue (ClutterRGBA *self)
 {
@@ -426,6 +483,15 @@ clutter_rgba_get_blue (ClutterRGBA *self)
   return self->blue;
 }
 
+/**
+ * clutter_rgba_set_alpha:
+ * @self: a #ClutterRGBA
+ * @alpha: the opacity of the color
+ *
+ * Sets the opacity of a #ClutterRGBA.
+ *
+ * Since: 1.6
+ */
 void
 clutter_rgba_set_alpha (ClutterRGBA *self,
                         gdouble      alpha)
@@ -442,6 +508,16 @@ clutter_rgba_set_alpha (ClutterRGBA *self,
   g_object_notify_by_pspec (G_OBJECT (self), obj_props[PROP_ALPHA]);
 }
 
+/**
+ * clutter_rgba_get_alpha:
+ * @self: a #ClutterRGBA
+ *
+ * Retrieves the opacity of a #ClutterRGBA.
+ *
+ * Return value: the opacity, between 0.0 and 1.0
+ *
+ * Since: 1.6
+ */
 gdouble
 clutter_rgba_get_alpha (ClutterRGBA *self)
 {
@@ -455,7 +531,7 @@ clutter_rgba_get_alpha (ClutterRGBA *self)
  * @self: a #ClutterRGBA
  * @color: a #ClutterColor
  *
- * Sets the color values of a #ClutterRGBA using a #ClutterColor.
+ * Sets the channels of a #ClutterRGBA using a #ClutterColor.
  *
  * Since: 1.6
  */
@@ -486,7 +562,7 @@ clutter_rgba_set_color (ClutterRGBA        *self,
  * @self: a #ClutterRGBA
  * @string: a color definition, as parseable by clutter_color_from_string()
  *
- * Sets the color values of a #ClutterRGBA using a @string definition.
+ * Sets the channels of a #ClutterRGBA using a @string definition.
  *
  * Since: 1.6
  */
@@ -191,14 +191,14 @@ clutter_rgba_class_init (ClutterRGBAClass *klass)
    * ClutterRGBA:red:
    *
-   * The value of the red channel.
+   * The intensity of the red channel.
    *
    * Since: 1.6
@@ -206,14 +206,14 @@ clutter_rgba_class_init (ClutterRGBAClass *klass)
    * ClutterRGBA:green:
    *
-   * The value of the green channel.
+   * The intensity of the green channel.
    *
    * Since: 1.6
@@ -221,14 +221,14 @@ clutter_rgba_class_init (ClutterRGBAClass *klass)
    * ClutterRGBA:blue:
    *
-   * The value of the blue channel.
+   * The intensity of the blue channel.
    *
    * Since: 1.6
@@ -289,10 +289,10 @@ clutter_rgba_init (ClutterRGBA *self)
 /**
  * clutter_rgba_new:
- * @red: the value of the red channel, between 0 and 1
- * @green: the value of the green channel, between 0 and 1
- * @blue: the value of the blue channel, between 0 and 1
- * @alpha: the value of the alpha channel, between 0 and 1
+ * @red: the intensity of the red channel, between 0 and 1
+ * @green: the intensity of the green channel, between 0 and 1
+ * @blue: the intensity of the blue channel, between 0 and 1
+ * @alpha: the opacity, between 0 and 1
  *
  * Creates a new #ClutterRGBA object for the given color. This